%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

# mklibname should handle the special cases of library naming
%define major 6
%define libx11 %mklibname x11_ %{major}
%define develname %mklibname -d x11

%define xcbmajor 1
%define libxcb %mklibname x11-xcb %{xcbmajor}

%define subrel 1

Name: libx11
Summary: X Library
Version: 1.8.6
Release: %mkrel 1
Group: System/Libraries
License: MIT
URL: https://xorg.freedesktop.org
Source0: https://xorg.freedesktop.org/releases/individual/lib/libX11-%{version}.tar.xz
Provides: libxorg-x11
Patch0: libX11-1.3.5-fix-null-pointer.patch
Patch1: libx11-fix-segfault.diff
# (tv) fix bug #7797 (lack of support for mn_MN locale):
Patch2: libx11-add_mn_locale.diff
#
# CVE-2023-43785 (fix)
# https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/6858d468d9ca55fb4c5fd70b223dbc78a3358a7f
Patch3: 6858d468d9ca55fb4c5fd70b223dbc78a3358a7f.patch
#
# CVE-2023-43786 (fix)
# https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/204c3393c4c90a29ed6bef64e43849536e863a86
Patch4: 204c3393c4c90a29ed6bef64e43849536e863a86.patch
# CVE-2023-43786 (hardening)
# https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/73a37d5f2fcadd6540159b432a70d80f442ddf4a
Patch5: 73a37d5f2fcadd6540159b432a70d80f442ddf4a.patch
# https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/b4031fc023816aca07fbd592ed97010b9b48784b
Patch6: b4031fc023816aca07fbd592ed97010b9b48784b.patch
#
# CVE-2023-43787 (fix)
# https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/7916869d16bdd115ac5be30a67c3749907aea6a0
Patch7: 7916869d16bdd115ac5be30a67c3749907aea6a0.patch

BuildRequires: x11-util-macros		>= 1.1.5
BuildRequires: pkgconfig(xtrans)		>= 1.0.4
BuildRequires: pkgconfig(xdmcp)		>= 1.0.2
BuildRequires: pkgconfig(xau)		>= 1.0.3
BuildRequires: x11-proto-devel		>= 7.3
BuildRequires: pkgconfig(xcb)
%if !%{bootstrap}
BuildRequires: groff			> 1.19.1
BuildRequires: xmlto
%endif
BuildRequires: x11-sgml-doctools
BuildRequires: docbook-style-xsl

# because of %%{_datadir/X11} being owned by x11-server-common
Requires(pre): x11-server-common >= 1.4.0.90-13mdv

%description
%{name} contains the shared libraries that most X programs
need to run properly. These shared libraries are in a separate package in
order to reduce the disk space needed to run X applications on a machine
without an X server (i.e, over a network).

#-----------------------------------------------------------

%package -n %{libx11}
Summary: X Library
Group: Development/X11
Provides: %{name} = %{version}
Requires(post): grep
Requires(postun): grep coreutils

%description -n %{libx11}
%{name} contains the shared libraries that most X programs
need to run properly. These shared libraries are in a separate package in
order to reduce the disk space needed to run X applications on a machine
without an X server (i.e, over a network).

%files -n %{libx11}
%{_libdir}/libX11.so.%{major}
%{_libdir}/libX11.so.%{major}.*

%post -n %{libx11}
if  grep -q "^%{_prefix}/X11R6/lib$" /etc/ld.so.conf; then
    grep -v "^%{_prefix}/X11R6/lib$" /etc/ld.so.conf > /etc/ld.so.conf.new
    mv -f /etc/ld.so.conf.new /etc/ld.so.conf
    /sbin/ldconfig
fi

%postun -n %{libx11}
if [ "$1" = "0" \
   -a "`grep "^%{_prefix}/X11R6/lib$" /etc/ld.so.conf`" != "" ]; then
    grep -v "^%{_prefix}/X11R6/lib$" /etc/ld.so.conf > /etc/ld.so.conf.new
    mv -f /etc/ld.so.conf.new /etc/ld.so.conf
    /sbin/ldconfig
fi

#-----------------------------------------------------------

%package -n %{libxcb}
Summary: X Library
Group: Development/X11
Provides: %{name}-xcb = %{version}
Conflicts: %{_lib}x11_6 < 1.6.1-2

%description -n %{libxcb}
%{name}-xcb contains the shared libraries that most X programs
need to run properly. These shared libraries are in a separate package in
order to reduce the disk space needed to run X applications on a machine
without an X server (i.e, over a network).

%files -n %{libxcb}
%{_libdir}/libX11-xcb.so.%{xcbmajor}
%{_libdir}/libX11-xcb.so.%{xcbmajor}.*

#-----------------------------------------------------------

%package -n %{develname}
Summary: Development files for %{name}
Group: Development/X11
Requires: %{libx11} = %{version}-%{release}
Requires: %{libxcb} = %{version}-%{release}
Provides: %{name}-devel = %{version}-%{release}
Provides: %{name}-xcb-devel = %{version}-%{release}
Conflicts: x11-proto-devel < 2019.2-2
Obsoletes: %{_lib}x11_6-devel < 1.5.99.902-2
Obsoletes: %{_lib}x11-static-devel < 1.6.1-2

%description -n %{develname}
%{name} includes the libraries and header files you'll need to develop
programs which run in X clients. X11 includes the base Xlib library as
well as the Xt and Xaw widget sets.

Install %{name} if you are going to develop programs which
will run as X clients.

%files -n %{develname}
%{_mandir}/man3/*.3.*
%{_libdir}/libX11.so
%{_libdir}/pkgconfig/x11.pc
%{_includedir}/X11/cursorfont.h
%{_includedir}/X11/ImUtil.h
%{_includedir}/X11/Xlocale.h
%{_includedir}/X11/Xcms.h
%{_includedir}/X11/Xlibint.h
%{_includedir}/X11/Xlib.h
%{_includedir}/X11/Xresource.h
%{_includedir}/X11/Xregion.h
%{_includedir}/X11/Xutil.h
%{_includedir}/X11/XlibConf.h
%{_includedir}/X11/XKBlib.h
%{_includedir}/X11/extensions/XKBgeom.h
%{_libdir}/libX11-xcb.so
%{_libdir}/pkgconfig/x11-xcb.pc
%{_includedir}/X11/Xlib-xcb.h
%{_mandir}/man5/*.5*

#-----------------------------------------------------------

%package common
Summary: Common files used by the X.org
Group: System/X11

%description common
Common files used by the X.org

%files common
%dir %{_datadir}/X11/locale
%{_datadir}/X11/locale/*
%{_datadir}/X11/Xcms.txt
%{_datadir}/X11/XErrorDB

#-----------------------------------------------------------

%package doc
Summary: Documentation for %{name}
Group: Documentation
BuildArch: noarch
Conflicts: libx11-devel < 1.4.99.1-3.mga2

%description doc
This package includes the documentation for the base Xlib library.

For guidance on programming with these libraries, O'Reilly & Associates
produces a series on X programming which you might find useful.

%files doc
%dir %{_docdir}/libX11
%{_docdir}/libX11/*

#-----------------------------------------------------------

%prep
%autosetup -p1 -n libX11-%{version}

%build
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install

find %{buildroot} -name "*.la" -delete


%changelog
* Wed Oct 11 2023 ns80 <ns80> 1.8.6-1.1.mga9
+ Revision: 1994493
- add fixes and hardening for CVE-4378[5-7] (mga#32358)

* Fri Jun 16 2023 ns80 <ns80> 1.8.6-1.mga9
+ Revision: 1962102
- new version 1.8.6 for CVE-2023-3138 (mga#32015)

* Tue Feb 07 2023 luigiwalser <luigiwalser> 1.8.4-1.mga9
+ Revision: 1939211
- 1.8.4
- remove upstream patches 3 and 4

* Wed Jan 18 2023 akien <akien> 1.8.3-2.mga9
+ Revision: 1934323
- Backport upstream PR 176 to attempt fixing crashes for Godot and other games

* Wed Jan 18 2023 luigiwalser <luigiwalser> 1.8.3-1.mga9
+ Revision: 1934182
- 1.8.3
- add patch from fedora to fix XPutBackEvent() issues (rhbz#2161020)

* Wed Nov 16 2022 luigiwalser <luigiwalser> 1.8.2-1.mga9
+ Revision: 1908068
- 1.8.2

* Wed Jun 29 2022 tv <tv> 1.8.1-1.mga9
+ Revision: 1866673
- libX11 1.8.1

* Wed Apr 06 2022 tv <tv> 1.7.5-1.mga9
+ Revision: 1846237
- 1.7.5

* Sat Mar 19 2022 umeabot <umeabot> 1.7.3.1-2.mga9
+ Revision: 1800086
- Mageia 9 Mass Rebuild

* Mon Dec 13 2021 luigiwalser <luigiwalser> 1.7.3.1-1.mga9
+ Revision: 1761993
- 1.7.3.1
- remove upstream patch

* Sat Aug 28 2021 tv <tv> 1.7.2-2.mga9
+ Revision: 1743293
- Parse the new _EVDEVK symbols

* Mon Jun 14 2021 tv <tv> 1.7.2-1.mga9
+ Revision: 1730685
- libX11 1.7.2
  (libX11 1.7.1 fixed CVE-2021-31535)

* Wed May 19 2021 neoclust <neoclust> 1.7.0-2.mga9
+ Revision: 1725712
- Add P100: Fixes CVE-2021-31535 (mga#28940)
+ tv <tv>
- use %%autosetup

* Sun Nov 22 2020 tv <tv> 1.7.0-1.mga8
+ Revision: 1648403
- 1.7.0

* Mon Nov 09 2020 tv <tv> 1.6.12-2.mga8
+ Revision: 1644125
- Fix a race-condition in poll_for_response (rhbz#1758384)

* Wed Aug 26 2020 tv <tv> 1.6.12-1.mga8
+ Revision: 1619078
- 1.6.12

* Tue Aug 04 2020 luigiwalser <luigiwalser> 1.6.10-2.mga8
+ Revision: 1610968
- add conflicts tag for header file moved from x11-proto-devel

* Sat Aug 01 2020 tv <tv> 1.6.10-1.mga8
+ Revision: 1610422
- 1.6.10
+ danf <danf>
- Switch URLs from http: to https:

* Sun Feb 16 2020 umeabot <umeabot> 1.6.9-2.mga8
+ Revision: 1536695
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 22 2019 tv <tv> 1.6.9-1.mga8
+ Revision: 1455209
- new release

* Wed Jul 03 2019 tv <tv> 1.6.8-1.mga8
+ Revision: 1417962
- new release

* Tue Oct 16 2018 tv <tv> 1.6.7-1.mga7
+ Revision: 1320824
- new release

* Thu Sep 27 2018 umeabot <umeabot> 1.6.6-3.mga7
+ Revision: 1308495
- Mageia 7 Mass Rebuild

* Tue Aug 21 2018 tv <tv> 1.6.6-1.mga7
+ Revision: 1253307
- new (security) release

* Wed Mar 01 2017 tv <tv> 1.6.5-1.mga6
+ Revision: 1088315
- new release

* Wed Oct 05 2016 luigiwalser <luigiwalser> 1.6.4-1.mga6
+ Revision: 1059056
- remove upstream patches
+ tv <tv>
- new release

* Fri Feb 12 2016 umeabot <umeabot> 1.6.3-3.mga6
+ Revision: 956010
- Mageia 6 Mass Rebuild

* Wed Sep 23 2015 luigiwalser <luigiwalser> 1.6.3-2.mga6
+ Revision: 882438
- add upstream patches to fix number wrapping bug (mga#13815)

* Sun Jun 21 2015 tv <tv> 1.6.3-1.mga6
+ Revision: 837519
- new release

* Wed Oct 15 2014 umeabot <umeabot> 1.6.2-5.mga5
+ Revision: 743526
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.6.2-4.mga5
+ Revision: 681863
- Mageia 5 Mass Rebuild

* Thu Feb 06 2014 tv <tv> 1.6.2-3.mga5
+ Revision: 584345
- rebuild for new proto

* Sat Oct 19 2013 umeabot <umeabot> 1.6.2-2.mga4
+ Revision: 534458
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 tv <tv> 1.6.2-1.mga4
+ Revision: 477896
- new release

* Thu Aug 22 2013 wally <wally> 1.6.1-2.mga4
+ Revision: 469502
- drop unneeded requires
- split out xcb lib
- drop old Mdv era conflicts
- drop static devel pkg

* Sun Aug 18 2013 fwang <fwang> 1.6.1-1.mga4
+ Revision: 467465
- new version 1.6.1

* Mon Jun 10 2013 tv <tv> 1.6.0-2.mga4
+ Revision: 441807
- patch 3: add support for mn_MN locale (mga#7797)

* Tue Jun 04 2013 tv <tv> 1.6.0-1.mga4
+ Revision: 437048
- new release

* Mon Jun 03 2013 fwang <fwang> 1.5.99.902-2.mga4
+ Revision: 435608
- update with correct libpolciy

* Fri May 24 2013 tv <tv> 1.5.99.902-1.mga4
+ Revision: 425955
- CVE release

* Thu May 23 2013 tv <tv> 1.5.99.901-1.mga4
+ Revision: 425507
- adjust file list
- new release

* Fri Feb 08 2013 luigiwalser <luigiwalser> 1.5.0-4.mga3
+ Revision: 397145
- remove obsolete pre script

* Sat Jan 12 2013 umeabot <umeabot> 1.5.0-3.mga3
+ Revision: 358497
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Oct 14 2012 ennael <ennael> 1.5.0-2.mga3
+ Revision: 305455
- Documentation group

* Wed Jun 06 2012 tv <tv> 1.5.0-1.mga3
+ Revision: 256262
- new release

* Fri Apr 13 2012 rtp <rtp> 1.4.99.1-4.mga2
+ Revision: 230677
- Rewrite workaround for libx11 Xrm segfault as it was breaking non
  threaded X applications (in this case, the mutex is _always_ null)

* Wed Apr 11 2012 blino <blino> 1.4.99.1-3.mga2
+ Revision: 230207
- split doc out of devel package so that i586 and x86_64 devel packages can be installed together
+ tv <tv>
- workaround a crash in gnome-control-center (#314)

* Tue Jan 31 2012 tv <tv> 1.4.99.1-1.mga2
+ Revision: 203736
- new release

* Mon Nov 21 2011 fwang <fwang> 1.4.4-2.mga2
+ Revision: 170273
- add br
- drop .la files
+ tv <tv>
- new release

* Tue Apr 12 2011 tv <tv> 1.4.3-1.mga1
+ Revision: 83559
- new release

* Thu Mar 24 2011 boklm <boklm> 1.4.2-3.mga1
+ Revision: 76186
- rebuild for bug #497

* Wed Mar 23 2011 boklm <boklm> 1.4.2-2.mga1
+ Revision: 76103
- rebuild for #497

* Tue Mar 22 2011 tv <tv> 1.4.2-1.mga1
+ Revision: 75576
- new release

* Fri Feb 18 2011 tv <tv> 1.4.1-1.mga1
+ Revision: 53920
- no %% in comments
- new release
+ rtp <rtp>
- Allow to break some circular BR (libx11->groff->gs->libx11, libx11->xmlto->tetex(xmltex)->libx11)

* Tue Jan 11 2011 dmorgan <dmorgan> 1.4.0-2.mga1
+ Revision: 6282
- imported package libx11


* Wed Dec 01 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.4.0-2mdv2011.0
+ Revision: 604584
- Require xmlto and x11-sgml-doctools for full documentation

* Mon Nov 22 2010 Thierry Vignaud <tv@mandriva.org> 1.4.0-1mdv2011.0
+ Revision: 599629
- new release

* Sat Oct 30 2010 Thierry Vignaud <tv@mandriva.org> 1.3.99.903-1mdv2011.0
+ Revision: 590399
- new release

* Wed Sep 22 2010 Thierry Vignaud <tv@mandriva.org> 1.3.99.902-1mdv2011.0
+ Revision: 580459
- fix file list

* Mon Sep 20 2010 Thierry Vignaud <tv@mandriva.org> 1.3.6-1mdv2011.0
+ Revision: 580293
- fix file list
- new release

* Fri Sep 17 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1.3.5-2mdv2011.0
+ Revision: 579264
- Patch0: fix segfault while passing null pointer (mdv #57779)

* Mon Aug 16 2010 Thierry Vignaud <tv@mandriva.org> 1.3.5-1mdv2011.0
+ Revision: 570273
- new release

* Wed Jul 21 2010 Thierry Vignaud <tv@mandriva.org> 1.3.4-1mdv2011.0
+ Revision: 556451
- new release

* Mon Jan 18 2010 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.3.3-1mdv2010.1
+ Revision: 493083
- New version: 1.3.3

* Tue Nov 24 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.3.2-3mdv2010.1
+ Revision: 469771
- Re-enable docs now that we have a working groff

* Mon Nov 09 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.3.2-2mdv2010.1
+ Revision: 463681
- New version: 1.3.2

* Tue Oct 27 2009 Paulo Ricardo Zanoni <pzanoni@mandriva.com> 1.2.2-2mdv2010.0
+ Revision: 459588
- Remove debug flags

* Fri Jul 10 2009 Colin Guthrie <cguthrie@mandriva.org> 1.2.2-1mdv2010.0
+ Revision: 394185
- New version: 1.2.2

* Wed May 20 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 1.2.1-2mdv2010.0
+ Revision: 378096
- use upstream compose and locale databases. The custom databases were
  supposed to ease the maintanence of these files, but they haven't been
  update in a long time.
- remove patch applied upstream

* Wed Apr 08 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 1.2.1-1mdv2009.1
+ Revision: 365222
- New version 1.2.1

* Tue Feb 17 2009 Colin Guthrie <cguthrie@mandriva.org> 1.2-1mdv2009.1
+ Revision: 342130
- New version: 1.2
- Try the upstream Compose.pre file (commit log says it's nicer now)

* Wed Feb 04 2009 Ander Conselvan de Oliveira <ander@mandriva.com> 1.1.99.2-4mdv2009.1
+ Revision: 337438
- Fix bug that caused hangs in applications such as Ekiga and OpenOffice(#45751)

* Thu Nov 06 2008 Colin Guthrie <cguthrie@mandriva.org> 1.1.99.2-3mdv2009.1
+ Revision: 300304
- Rebuild due to random failure on i586
- New version: 1.1.99.2 (rc)
- This uses the new libxcb socket handoff mechanism

  + Olivier Blin <oblin@mandriva.com>
    - rebuild with xcb
    - build temporarily without xcb

* Fri Sep 05 2008 Thierry Vignaud <tv@mandriva.org> 1.1.5-1mdv2009.0
+ Revision: 281261
- fix xcb-devel BuildRequires
- new release
- remove merged patches
- fix group

* Thu Aug 07 2008 Ander Conselvan de Oliveira <ander@mandriva.com> 1.1.4-5mdv2009.0
+ Revision: 266990
- Fix quoting issue in postun scriptlet (bug #42569)

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1.1.4-4mdv2009.0
+ Revision: 264937
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Mon May 26 2008 Paulo Andrade <pcpa@mandriva.com.br> 1.1.4-3mdv2009.0
+ Revision: 211452
- o Cherry pick some commits added after libX11-1.1.4 tag
  o Don't add /usr/X11R6/lib to ld.so.conf in %%post, and now, also remove
  it in %%pre as it causes problems with recent changes to make /usr/X11R6
  a symlink to /usr.

* Mon May 05 2008 Paulo Andrade <pcpa@mandriva.com.br> 1.1.4-2mdv2009.0
+ Revision: 201575
- Change ownership of %%{_datadir}/X11 to x11-server-common package.

* Mon Apr 14 2008 Paulo Andrade <pcpa@mandriva.com.br> 1.1.4-1mdv2009.0
+ Revision: 192981
- Update to version 1.1.4.

* Mon Mar 31 2008 Anssi Hannula <anssi@mandriva.org> 1.1.3-6mdv2008.1
+ Revision: 191311
- move the script requires added in last release to binary package

* Sat Mar 01 2008 Olivier Blin <oblin@mandriva.com> 1.1.3-5mdv2008.1
+ Revision: 176984
- require grep in post script (and coreutils in postun)

* Fri Feb 08 2008 Paulo Andrade <pcpa@mandriva.com.br> 1.1.3-4mdv2008.1
+ Revision: 164304
- Enable xcb in libx11 build.
  Note that the real libX11.so changes are minimal, and to actually
  use xcb, it is required to explicitly link with libX11-xcb.so, and
  it should be better to also use xcb-devel headers (but there should
  not exist any binary incompatibility).
  One could also try the luck with a command like:
  LD_PRELOAD=/usr/lib/libX11-xcb.so run-some-program

* Mon Jan 14 2008 Paulo Andrade <pcpa@mandriva.com.br> 1.1.3-3mdv2008.1
+ Revision: 151524
- Update BuildRequires and rebuild.

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Colin Guthrie <cguthrie@mandriva.org>
    - Conditionally include files from XCB enable build.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Sep 28 2007 Frederic Crozat <fcrozat@mandriva.com> 1.1.3-2mdv2008.0
+ Revision: 93530
- Patch0 (GIT): add missing keys to XKeysymDB (Mdv bug #34247)

* Fri Aug 03 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.1.3-1mdv2008.0
+ Revision: 58399
- drop patch 0 (merged upstream)
- new upstream version 1.1.3

  + Ademar de Souza Reis Jr <ademar@mandriva.com.br>
    - add missing libxcb build-requirement
    - build section cleanup

* Sun Jun 10 2007 Olivier Blin <oblin@mandriva.com> 1.1.2-2mdv2008.0
+ Revision: 37943
- fix XGetMotionEvents prototype (should fix gimp paintbrush, submitted as upstream bug #11222)
- use -a option for automake and run autoheader (to ease building from git)

* Mon Jun 04 2007 Ademar de Souza Reis Jr <ademar@mandriva.com.br> 1.1.2-1mdv2008.0
+ Revision: 35178
- new upstream version: 1.1.2
- remove patch already applied (CVE-2007-1667)

* Thu May 03 2007 Ademar de Souza Reis Jr <ademar@mandriva.com.br> 1.1.1-3mdv2008.0
+ Revision: 22005
- add patch for CVE-2007-1667 (see #29818 comments)


* Sun Feb 18 2007 Götz Waschk <waschk@mandriva.org> 1.1.1-2mdv2007.0
+ Revision: 122277
- rebuild for pkgconfig deps

* Fri Feb 09 2007 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.1.1-1mdv2007.1
+ Revision: 118504
- new upstream release: 1.1.1

  + Pablo Saratxaga <pablo@mandriva.com>
    - merged {compose,locale}.dir with X11.org files
    - zh_HK.UTF-
    - added recognition of more locales (now in sync with DrakX)

* Thu Nov 16 2006 Pablo Saratxaga <pablo@mandriva.com> 1.0.3-3mdv2007.1
+ Revision: 84844
- improved default UTF-8 Compose file
- improved {locale,compose}.{dir,alias} with definitions for all our locales

* Fri Jul 07 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.3-2mdv2007.0
+ Revision: 38413
- Removed wrong requires for mkcomposecache. Thanks for Stefan van der Eijk for pointing that.

  + Thierry Vignaud <tvignaud@mandriva.com>
    - fix group

* Tue Jul 04 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.3-1mdv2007.0
+ Revision: 38293
- new upstream release (1.0.3):
  * Fix Compose Cache
  * One instance of checking the setuid() return value was missed

* Thu Jun 29 2006 Gustavo Pichorim Boiko <boiko@mandriva.com> 1.0.2-1mdv2007.0
+ Revision: 38132
- new upstream release (1.0.2). Highlights:
  * i18n: Separate data and lib directories
  * Break out locale data into separate data and library directories, under
  $(datadir) and $(libdir), respectively, by default.
  * im: add Braille input method (#6296)
  * fdo bug #3104: Compose table cache for faster X11 application starts.
  * Set XTHREADLIB correctly for dragonfly platforms.
  * Fix threading support on GNU/kFreeBSD systems.
  * Check setuid() return value
- removed patch for braille support (this release already has that)
- rebuild to fix cooker uploading
- renamed libx11_6-common to libx11-common
- increment release
- fixed more dependencies
- Adding X.org 7.0 to the repository

  + Frederic Crozat <fcrozat@mandriva.com>
    - Release 1.0.1
      Patch0 (GIT): add braille input method support

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Laurent Montel <lmontel@mandriva.com>
    - Fix conflict on x86_64

  + Thierry Vignaud <tvignaud@mandriva.com>
    - provides/obsoletes libxorg-x11 (so that updates work smoothly)

